/** ogftp.c
 **
 ** Omnigo/Unix file transfer program.
 **
 ** Written by and Copyright 1996 Asher Hoskins.
 ** Modified by Marcus Groeber for use under OS/2.
 **
 ** The author retains copyright on this implementation. Permission for
 ** educational and non-profit use is granted to all. If you're planning to
 ** make money with this or any code derived from it, check with the author
 ** first.
 **
 ** See README file for more information.
 **
 ** Open a connection to the Omnigo.
 **/


#include <stdio.h>
#include <ctype.h>
#include <string.h>
#include <fcntl.h>
#ifdef LINUX
	#include <termios.h>
	#define CNUL 0
#else
	#include <termio.h>
#endif


/** Open a connection to the Omnigo.
 **/

int openOmnigo(char *port, unsigned int speed) {

	int tty, i;
	struct termio attr;
	unsigned int speedFlag;

	switch(speed) {
	case 2400:
		speedFlag = B2400;
		break;
	case 9600:
		speedFlag = B9600;
		break;
	case 19200:
		speedFlag = B19200;
		break;
	default:
		fputs("Illegal speed!\n", stderr);
		exit(1);
	}

	if ((tty=open(port, O_RDWR)) == -1) {
		fputs("Couldn't open port!\n", stderr);
		exit(1);
	}

	ioctl(tty, TCGETA, &attr);

	attr.c_iflag = IGNBRK;
	attr.c_oflag = 0;
	attr.c_lflag = 0;
	#ifdef SGI
		attr.c_cflag = speedFlag|CS8|HUPCL|CREAD|CNEW_RTSCTS;
	#else
		attr.c_cflag = speedFlag|CS8|HUPCL|CREAD|CRTSCTS;
	#endif
	attr.c_line = 0;

	for (i=0; i<NCC; i++)
		attr.c_cc[i] = CNUL;

	attr.c_cc[VTIME] = 0;
	attr.c_cc[VMIN] = 1;

	ioctl(tty, TCSETA, &attr);

	return(tty);
}
